==> xlniuxdata-vipgame-1.0.7-20150331.092636-2-sources.jar: com/xunlei/niux/data/vipgame/vo/gift/GiftFlow.java <==
package com.xunlei.niux.data.vipgame.vo.gift;

import com.ferret.common.dao.annotation.Table;

@Table(tableName="giftflow",pkFieldAssign=false,pkFieldName="flowId")
public class GiftFlow {
	private Long flowId;
	private Long giftId;
	private String userId;
	private String gameId;
	private String serverId;
	private String roleId;
	private Integer giftNum;
	private String flowStatus;
	private String flowTime;
	private String dealTime;
	private String failCause;
	private String actNo;
	private String thirdOrderNo;
	private String serialNum;
	private String flowtimestamp;
	private String showLocNo;
	
	public String getShowLocNo() {
		return showLocNo;
	}
	public void setShowLocNo(String showLocNo) {
		this.showLocNo = showLocNo;
	}
	public Long getFlowId() {
		return flowId;
	}
	public void setFlowId(Long flowId) {
		this.flowId = flowId;
	}
	public Long getGiftId() {
		return giftId;
	}
	public void setGiftId(Long giftId) {
		this.giftId = giftId;
	}
	public String getUserId() {
		return userId;
	}
	public void setUserId(String userId) {
		this.userId = userId;
	}
	public String getGameId() {
		return gameId;
	}
	public void setGameId(String gameId) {
		this.gameId = gameId;
	}
	public String getServerId() {
		return serverId;
	}
	public void setServerId(String serverId) {
		this.serverId = serverId;
	}
	public String getRoleId() {
		return roleId;
	}
	public void setRoleId(String roleId) {
		this.roleId = roleId;
	}
	public Integer getGiftNum() {
		return giftNum;
	}
	public void setGiftNum(Integer giftNum) {
		this.giftNum = giftNum;
	}
	public String getFlowStatus() {
		return flowStatus;
	}
	public void setFlowStatus(String flowStatus) {
		this.flowStatus = flowStatus;
	}
	public String getFlowTime() {
		return flowTime;
	}
	public void setFlowTime(String flowTime) {
		this.flowTime = flowTime;
	}
	public String getDealTime() {
		return dealTime;
	}
	public void setDealTime(String dealTime) {
		this.dealTime = dealTime;
	}
	public String getFailCause() {
		return failCause;
	}
	public void setFailCause(String failCause) {
		this.failCause = failCause;
	}
	public String getActNo() {
		return actNo;
	}
	public void setActNo(String actNo) {
		this.actNo = actNo;
	}
	public String getThirdOrderNo() {
		return thirdOrderNo;
	}
	public void setThirdOrderNo(String thirdOrderNo) {
		this.thirdOrderNo = thirdOrderNo;
	}
	public String getSerialNum() {
		return serialNum;
	}
	public void setSerialNum(String serialNum) {
		this.serialNum = serialNum;
	}
	public String getFlowtimestamp() {
		return flowtimestamp;
	}
	public void setFlowtimestamp(String flowtimestamp) {
		this.flowtimestamp = flowtimestamp;
	}
}

==> xlniuxdata-vipgame-1.0.65-20161114.113332-33-sources.jar: com/xunlei/niux/data/vipgame/vo/gift/GiftFlow.java <==
package com.xunlei.niux.data.vipgame.vo.gift;

import com.ferret.common.dao.annotation.Table;

@Table(tableName="giftflow",pkFieldAssign=false,pkFieldName="flowId")
public class GiftFlow {
	private Long flowId;
	private Long giftId;
	private String userId;
	private String gameId;
	private String serverId;
	private String roleId;
	private Integer giftNum;
	private String flowStatus;
	private String flowTime;
	private String dealTime;
	private String failCause;
	private String actNo;
	private String thirdOrderNo;
	private String serialNum;
	private String flowtimestamp;
	private String showLocNo;
    private String expireDate;
	
	public String getShowLocNo() {
		return showLocNo;
	}
	public void setShowLocNo(String showLocNo) {
		this.showLocNo = showLocNo;
	}
	public Long getFlowId() {
		return flowId;
	}
	public void setFlowId(Long flowId) {
		this.flowId = flowId;
	}
	public Long getGiftId() {
		return giftId;
	}
	public void setGiftId(Long giftId) {
		this.giftId = giftId;
	}
	public String getUserId() {
		return userId;
	}
	public void setUserId(String userId) {
		this.userId = userId;
	}
	public String getGameId() {
		return gameId;
	}
	public void setGameId(String gameId) {
		this.gameId = gameId;
	}
	public String getServerId() {
		return serverId;
	}
	public void setServerId(String serverId) {
		this.serverId = serverId;
	}
	public String getRoleId() {
		return roleId;
	}
	public void setRoleId(String roleId) {
		this.roleId = roleId;
	}
	public Integer getGiftNum() {
		return giftNum;
	}
	public void setGiftNum(Integer giftNum) {
		this.giftNum = giftNum;
	}
	public String getFlowStatus() {
		return flowStatus;
	}
	public void setFlowStatus(String flowStatus) {
		this.flowStatus = flowStatus;
	}
	public String getFlowTime() {
		return flowTime;
	}
	public void setFlowTime(String flowTime) {
		this.flowTime = flowTime;
	}
	public String getDealTime() {
		return dealTime;
	}
	public void setDealTime(String dealTime) {
		this.dealTime = dealTime;
	}
	public String getFailCause() {
		return failCause;
	}
	public void setFailCause(String failCause) {
		this.failCause = failCause;
	}
	public String getActNo() {
		return actNo;
	}
	public void setActNo(String actNo) {
		this.actNo = actNo;
	}
	public String getThirdOrderNo() {
		return thirdOrderNo;
	}
	public void setThirdOrderNo(String thirdOrderNo) {
		this.thirdOrderNo = thirdOrderNo;
	}
	public String getSerialNum() {
		return serialNum;
	}
	public void setSerialNum(String serialNum) {
		this.serialNum = serialNum;
	}
	public String getFlowtimestamp() {
		return flowtimestamp;
	}
	public void setFlowtimestamp(String flowtimestamp) {
		this.flowtimestamp = flowtimestamp;
	}

    public String getExpireDate() {
        return expireDate;
    }

    public void setExpireDate(String expireDate) {
        this.expireDate = expireDate;
    }
}
